@@ -1,6 +1,8 @@
 import json
 import logging
 from abc import abstractmethod
+from typing import Dict
+from collections import defaultdict
 from cloudsplaining.scan.policy_document import PolicyDocument
 
 from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
@@ -11,6 +13,10 @@ from checkov.cloudformation.checks.utils.iam_cloudformation_document_to_policy_c
 
 
 class BaseCloudsplainingIAMCheck(BaseResourceCheck):
+    # creating a PolicyDocument is computational expensive,
+    # therefore a cache is defined at class level
+    policy_document_cache: Dict[str, Dict[str, PolicyDocument]] = defaultdict(lambda: defaultdict(PolicyDocument))
+
     def __init__(self, name, id):
         super().__init__(name=name, id=id, categories=[CheckCategories.IAM],
             supported_resources=["AWS::IAM::Policy", "AWS::IAM::ManagedPolicy", "AWS::IAM::Group",
@@ -30,22 +36,30 @@ class BaseCloudsplainingIAMCheck(BaseResourceCheck):
             # Scan all policies
             for policy in policy_conf:
                 policy_doc_key = 'PolicyDocument'
-                if isinstance(policy, dict) and policy_doc_key in policy.keys():
-                    # When using unresolved Cfn functions, policy is an str
-                    policy_doc = policy[policy_doc_key]
-                    try:
+                if not isinstance(policy, dict) or policy_doc_key not in policy.keys():
+                    continue
+                policy_statement = None
+                policy_name = policy.get("PolicyName")
+                if isinstance(policy_name, str):
+                    policy_statement = self.policy_document_cache.get(self.entity_path, {}).get(policy.get("PolicyName"))
+
+                try:
+                    if not policy_statement:
+                        # When using unresolved Cfn functions, policy is an str
+                        policy_doc = policy[policy_doc_key]
                         converted_policy_doc = convert_cloudformation_conf_to_iam_policy(policy_doc)
                         statement_key = 'Statement'
                         if statement_key in converted_policy_doc:
                             policy_statement = PolicyDocument(converted_policy_doc)
-                            violations = self.cloudsplaining_analysis(policy_statement)
-                            if violations:
-                                logging.debug("detailed cloudsplaining finding: {}",json.dumps(violations))
-                                return CheckResult.FAILED
-                    except Exception:
-                        # this might occur with templated iam policies where ARN is not in place or similar
-                        logging.debug("could not run cloudsplaining analysis on policy {}", conf)
-                        return CheckResult.UNKNOWN
+                            self.policy_document_cache[self.entity_path][policy.get("PolicyName")] = policy_statement
+                    violations = self.cloudsplaining_analysis(policy_statement)
+                    if violations:
+                        logging.debug("detailed cloudsplaining finding: {}", json.dumps(violations))
+                        return CheckResult.FAILED
+                except Exception:
+                    # this might occur with templated iam policies where ARN is not in place or similar
+                    logging.debug("could not run cloudsplaining analysis on policy {}", conf)
+                    return CheckResult.UNKNOWN
             return CheckResult.PASSED
 
     @multi_signature()
