@@ -7,7 +7,7 @@ class APIGatewayAccessLogging(BaseResourceValueCheck):
     def __init__(self):
         name = "Ensure API Gateway has Access Logging enabled"
         id = "CKV_AWS_76"
-        supported_resources = ['AWS::ApiGateway::Stage']
+        supported_resources = ['AWS::ApiGateway::Stage', "AWS::Serverless::Api"]
         categories = [CheckCategories.LOGGING]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
