@@ -8,7 +8,7 @@ class LambdaEnvironmentEncryptionSettings(BaseResourceCheck):
     def __init__(self):
         name = "Check encryption settings for Lambda environmental variable"
         id = "CKV_AWS_173"
-        supported_resources = ['AWS::Lambda::Function']
+        supported_resources = ['AWS::Lambda::Function', "AWS::Serverless::Function"]
         categories = [CheckCategories.ENCRYPTION]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
