@@ -1,5 +1,7 @@
+from typing import List
+
 from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
-from checkov.common.parsers.node import dict_node
+from checkov.common.parsers.node import DictNode
 from checkov.common.models.enums import CheckResult, CheckCategories
 
 
@@ -11,7 +13,7 @@ class NeptuneClusterLogging(BaseResourceCheck):
         categories = [CheckCategories.LOGGING]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
-    def scan_resource_conf(self, conf: dict_node) -> CheckResult:
+    def scan_resource_conf(self, conf: DictNode) -> CheckResult:
         log_types = ["audit"]
 
         logs_exports = conf.get("Properties", {}).get("EnableCloudwatchLogsExports", [])
@@ -20,5 +22,7 @@ class NeptuneClusterLogging(BaseResourceCheck):
 
         return CheckResult.FAILED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ["Properties/EnableCloudwatchLogsExports"]
 
 check = NeptuneClusterLogging()
