@@ -80,7 +80,8 @@ class NodeConstructor(SafeConstructor):
         for key_node, value_node in node.value:
             key = self.construct_object(key_node, False)
             value = self.construct_object(value_node, False)
-
+            if isinstance(key, dict):
+                key = frozenset(key.keys()), frozenset(key.values())
             if key in mapping:
                 raise CfnParseError(
                     self.filename,
@@ -99,8 +100,8 @@ class NodeConstructor(SafeConstructor):
 
     def construct_yaml_seq(self, node):
         obj, = SafeConstructor.construct_yaml_seq(self, node)
-        assert isinstance(obj, list) # nosec
-        return ListNode(obj, node.start_mark, node.end_mark) # nosec
+        assert isinstance(obj, list)  # nosec
+        return ListNode(obj, node.start_mark, node.end_mark)  # nosec
 
     def construct_yaml_null_error(self, node):
         """Throw a null error"""
