@@ -1,9 +1,11 @@
+from __future__ import annotations
+
 import logging
 from abc import abstractmethod
 from collections.abc import Iterable
 from typing import List, Dict, Any, Callable, Optional
 
-from checkov.common.typing import _SkippedCheck
+from checkov.common.typing import _SkippedCheck, _CheckResult
 from checkov.common.util.type_forcers import force_list
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.common.multi_signature import MultiSignatureMeta, multi_signature
@@ -14,6 +16,8 @@ class BaseCheck(metaclass=MultiSignatureMeta):
     name = ""
     categories: "Iterable[CheckCategories]" = ()
     supported_entities: "Iterable[str]" = ()
+    block_type: str
+    path: Optional[str]
 
     def __init__(
         self,
@@ -36,6 +40,9 @@ class BaseCheck(metaclass=MultiSignatureMeta):
         self.entity_path = ""
         self.entity_type = ""
         self.guideline = guideline
+        self.benchmarks: dict[str, list[str]] = {}
+        self.severity = None
+        self.bc_category = None
         if self.guideline:
             logging.debug(f'Found custom guideline for check {id}')
 
@@ -46,8 +53,8 @@ class BaseCheck(metaclass=MultiSignatureMeta):
         entity_name: str,
         entity_type: str,
         skip_info: _SkippedCheck,
-    ) -> Dict[str, Any]:
-        check_result: Dict[str, Any] = {}
+    ) -> _CheckResult:
+        check_result: _CheckResult = {}
         if skip_info:
             check_result["result"] = CheckResult.SKIPPED
             check_result["suppress_comment"] = skip_info["suppress_comment"]
@@ -72,13 +79,11 @@ class BaseCheck(metaclass=MultiSignatureMeta):
                 )
                 self.logger.debug(message)
 
-            except Exception as e:
+            except Exception:
                 self.logger.error(
-                    "Failed to run check: {} for configuration: {} at file: {}".format(
-                        self.name, str(entity_configuration), scanned_file
-                    )
+                    f"Failed to run check: {self.name} for configuration: {entity_configuration} at file: {scanned_file}"
                 )
-                raise e
+                raise
         return check_result
 
     @multi_signature()
