@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 import json
 import logging
 import os
 from pathlib import Path
-from typing import Dict, Any, Optional, List
+from typing import Any, TYPE_CHECKING
 
 import yaml
 
@@ -12,13 +14,16 @@ from checkov.common.graph.checks_infra.registry import BaseRegistry
 from checkov.runner_filter import RunnerFilter
 from checkov.common.checks_infra.resources_types import resources_types
 
+if TYPE_CHECKING:
+    from checkov.common.graph.checks_infra.base_check import BaseGraphCheck
+
 CHECKS_POSSIBLE_ENDING = [".yaml", ".yml"]
 
 
 class Registry(BaseRegistry):
     def __init__(self, checks_dir: str, parser: BaseGraphCheckParser = BaseGraphCheckParser()) -> None:
         super().__init__(parser)
-        self.checks = []
+        self.checks: list[BaseGraphCheck] = []
         self.parser = parser
         self.checks_dir = checks_dir
         self.logger = logging.getLogger(__name__)
@@ -28,9 +33,9 @@ class Registry(BaseRegistry):
 
     def _load_checks_from_dir(self, directory: str, external_check: bool) -> None:
         dir = os.path.expanduser(directory)
-        self.logger.info("Loading external checks from {}".format(dir))
+        self.logger.debug("Loading external checks from {}".format(dir))
         for root, d_names, f_names in os.walk(dir):
-            self.logger.info(f"Searching through {d_names} and {f_names}")
+            self.logger.debug(f"Searching through {d_names} and {f_names}")
             for file in f_names:
                 file_ending = os.path.splitext(file)[1]
                 if file_ending in CHECKS_POSSIBLE_ENDING:
@@ -55,15 +60,15 @@ class Registry(BaseRegistry):
         self._load_checks_from_dir(dir, True)
 
     @staticmethod
-    def _get_resource_types(check_json: Dict[str, Dict[str, Any]]) -> Optional[List[str]]:
+    def _get_resource_types(check_json: dict[str, dict[str, Any]]) -> list[str] | None:
         provider = check_json.get("scope", {}).get("provider", "").lower()
         return resources_types.get(provider)
 
 
-_registry_instances = {}
+_registry_instances: dict[str, Registry] = {}
 
 
-def get_graph_checks_registry(check_type):
+def get_graph_checks_registry(check_type: str) -> Registry:
     if not _registry_instances.get(check_type):
         _registry_instances[check_type] = Registry(parser=NXGraphCheckParser(),
                              checks_dir=f"{Path(__file__).parent.parent.parent}/{check_type}/checks/graph_checks")
