@@ -1,6 +1,9 @@
+from __future__ import annotations
+
+import logging
 from json import JSONDecoder
 from json.decoder import WHITESPACE, WHITESPACE_STR, BACKSLASH, STRINGCHUNK, JSONArray
-from typing import List
+from typing import List, Any
 
 from json.scanner import NUMBER_RE
 
@@ -218,7 +221,7 @@ class Decoder(JSONDecoder):
         self.scan_once = py_make_scanner(self)
         self.newline_indexes = []
 
-    def decode(self, s):
+    def decode(self, s: str, _w: None = None) -> Any:
         """Overridden to retrieve indexes """
         self.newline_indexes = find_indexes(s)
         obj = super().decode(s)
@@ -296,7 +299,8 @@ class Decoder(JSONDecoder):
             try:
                 value, end = scan_once(s, end)
             except StopIteration as err:
-                raise DecodeError('Expecting value', s, str(err))
+                logging.error(err)
+                raise DecodeError('Expecting value', s, end_mark.line)
             key_str = StrNode(key, beg_mark, end_mark)
             pairs_append((key_str, value))
             try:
