@@ -1,26 +1,37 @@
+from __future__ import annotations
+
 import argparse
 import itertools
-from json import dumps
+import json
 import logging
 import os
+import re
 from abc import abstractmethod
-from typing import List, Union, Dict, Any, Tuple, Optional
+from collections import defaultdict
+from collections.abc import Iterable
+from json import dumps
+from pathlib import Path
+from typing import List, Dict, Any, Tuple, Optional, cast
 
 from typing_extensions import Literal
 
+from checkov.common.bridgecrew.integration_features.features.policy_metadata_integration import \
+    integration as metadata_integration
 from checkov.common.bridgecrew.integration_features.integration_feature_registry import integration_feature_registry
+from checkov.common.images.image_referencer import ImageReferencer
 from checkov.common.output.baseline import Baseline
 from checkov.common.output.report import Report
+from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.runners.base_runner import BaseRunner
 from checkov.common.util import data_structures_utils
+from checkov.common.util.banner import tool as tool_name
+from checkov.common.util.ext_cyclonedx_xml import ExtXml
 from checkov.common.util.json_utils import CustomJSONEncoder
 from checkov.runner_filter import RunnerFilter
+from checkov.sca_image.runner import Runner as image_runner
 from checkov.terraform.context_parsers.registry import parser_registry
-from checkov.terraform.runner import Runner as tf_runner
 from checkov.terraform.parser import Parser
-from checkov.common.parallelizer.parallel_runner import parallel_runner
-from checkov.common.util.ext_cyclonedx_xml import ExtXml
-from checkov.common.util.banner import tool as tool_name
+from checkov.terraform.runner import Runner as tf_runner
 
 CHECK_BLOCK_TYPES = frozenset(["resource", "data", "provider", "module"])
 OUTPUT_CHOICES = ["cli", "cyclonedx", "json", "junitxml", "github_failed_only", "sarif"]
@@ -38,53 +49,67 @@ class RunnerRegistry:
         self.runners = list(runners)
         self.banner = banner
         self.scan_reports = []
+        self.image_referencing_runners = self._get_image_referencing_runners()
         self.filter_runner_framework()
         self.tool = tool_name
+        for runner in runners:
+            if isinstance(runner, image_runner):
+                runner.image_referencers = self.image_referencing_runners
 
     @abstractmethod
     def extract_entity_details(self, entity: Dict[str, Any]) -> Tuple[str, str, Dict[str, Any]]:
         raise NotImplementedError()
 
     def run(
-        self,
-        root_folder: Optional[str] = None,
-        external_checks_dir: Optional[List[str]] = None,
-        files: Optional[List[str]] = None,
-        guidelines: Optional[Dict[str, str]] = None,
-        collect_skip_comments: bool = True,
-        repo_root_for_plan_enrichment: Optional[List[Union[str, os.PathLike]]] = None,
+            self,
+            root_folder: Optional[str] = None,
+            external_checks_dir: Optional[List[str]] = None,
+            files: Optional[List[str]] = None,
+            collect_skip_comments: bool = True,
+            repo_root_for_plan_enrichment: list[str | Path] | None = None,
     ) -> List[Report]:
         integration_feature_registry.run_pre_runner()
         if len(self.runners) == 1:
-            reports = [self.runners[0].run(root_folder, external_checks_dir=external_checks_dir, files=files,
-                                           runner_filter=self.runner_filter, collect_skip_comments=collect_skip_comments)]
+            reports: Iterable[Report] = [self.runners[0].run(root_folder, external_checks_dir=external_checks_dir, files=files,
+                                           runner_filter=self.runner_filter,
+                                           collect_skip_comments=collect_skip_comments)]
         else:
             reports = parallel_runner.run_function(
                 lambda runner: runner.run(root_folder, external_checks_dir=external_checks_dir, files=files,
-                                          runner_filter=self.runner_filter, collect_skip_comments=collect_skip_comments),
+                                          runner_filter=self.runner_filter,
+                                          collect_skip_comments=collect_skip_comments),
                 self.runners, 1)
 
         for scan_report in reports:
-            self._handle_report(scan_report, guidelines, repo_root_for_plan_enrichment)
+            self._handle_report(scan_report, repo_root_for_plan_enrichment)
         return self.scan_reports
 
-    def _handle_report(self, scan_report, guidelines, repo_root_for_plan_enrichment):
+    def _handle_report(self, scan_report: Report, repo_root_for_plan_enrichment: list[str | Path] | None) -> None:
         integration_feature_registry.run_post_runner(scan_report)
-        if guidelines:
-            RunnerRegistry.enrich_report_with_guidelines(scan_report, guidelines)
+        if metadata_integration.check_metadata:
+            RunnerRegistry.enrich_report_with_guidelines(scan_report)
         if repo_root_for_plan_enrichment:
             enriched_resources = RunnerRegistry.get_enriched_resources(repo_root_for_plan_enrichment)
             scan_report = Report("terraform_plan").enrich_plan_report(scan_report, enriched_resources)
             scan_report = Report("terraform_plan").handle_skipped_checks(scan_report, enriched_resources)
         self.scan_reports.append(scan_report)
 
+    def save_output_to_file(self, file_name: str, data: str, data_format: str) -> None:
+        try:
+            with open(file_name, 'w') as f:
+                f.write(data)
+            logging.info(f"\nWrote output in {data_format} format to the file '{file_name}')")
+        except EnvironmentError:
+            logging.error(f"\nAn error occurred while writing {data_format} results to file: {file_name}",
+                          exc_info=True)
+
     def print_reports(
-        self,
-        scan_reports: List[Report],
-        config: argparse.Namespace,
-        url: Optional[str] = None,
-        created_baseline_path: Optional[str] = None,
-        baseline: Optional[Baseline] = None,
+            self,
+            scan_reports: List[Report],
+            config: argparse.Namespace,
+            url: Optional[str] = None,
+            created_baseline_path: Optional[str] = None,
+            baseline: Optional[Baseline] = None,
     ) -> Literal[0, 1]:
         output_formats = set(config.output)
 
@@ -96,32 +121,38 @@ class RunnerRegistry:
         sarif_reports = []
         junit_reports = []
         cyclonedx_reports = []
+        data_outputs: dict[str, str] = defaultdict(str)
         for report in scan_reports:
             if not report.is_empty():
                 if "json" in config.output:
                     report_jsons.append(report.get_dict(is_quiet=config.quiet, url=url))
                 if "junitxml" in config.output:
                     junit_reports.append(report)
-                    # report.print_junit_xml()
                 if "github_failed_only" in config.output:
-                    report.print_failed_github_md(use_bc_ids=config.output_bc_ids)
+                    data_outputs["github_failed_only"] += report.print_failed_github_md(use_bc_ids=config.output_bc_ids)
                 if "sarif" in config.output:
                     sarif_reports.append(report)
                 if "cli" in config.output:
                     cli_reports.append(report)
                 if "cyclonedx" in config.output:
                     cyclonedx_reports.append(report)
+            logging.debug(f'Getting exit code for report {report.check_type}')
             exit_codes.append(report.get_exit_code(config.soft_fail, config.soft_fail_on, config.hard_fail_on))
 
         if "cli" in config.output:
+            cli_output = ''
             for report in cli_reports:
-                report.print_console(
+                cli_output += report.print_console(
                     is_quiet=config.quiet,
                     is_compact=config.compact,
                     created_baseline_path=created_baseline_path,
                     baseline=baseline,
                     use_bc_ids=config.output_bc_ids,
                 )
+            print(cli_output)
+            # Remove colors from the cli output
+            ansi_escape = re.compile(r'(?:\x1B[@-_]|[\x80-\x9F])[0-?]*[ -/]*[@-~]')
+            data_outputs['cli'] = ansi_escape.sub('', cli_output)
             if url:
                 print("More details: {}".format(url))
             output_formats.remove("cli")
@@ -131,45 +162,54 @@ class RunnerRegistry:
             master_report = Report("merged")
             print(self.banner)
             for report in sarif_reports:
-                report.print_console(
-                        is_quiet=config.quiet,
-                        is_compact=config.compact,
-                        created_baseline_path=created_baseline_path,
-                        baseline=baseline,
-                        use_bc_ids=config.output_bc_ids,
-                )
+                print(report.print_console(
+                    is_quiet=config.quiet,
+                    is_compact=config.compact,
+                    created_baseline_path=created_baseline_path,
+                    baseline=baseline,
+                    use_bc_ids=config.output_bc_ids,
+                ))
                 master_report.failed_checks += report.failed_checks
                 master_report.skipped_checks += report.skipped_checks
             if url:
                 print("More details: {}".format(url))
             master_report.write_sarif_output(self.tool)
+            data_outputs['sarif'] = json.dumps(master_report.get_sarif_json(self.tool), cls=CustomJSONEncoder)
             output_formats.remove("sarif")
             if output_formats:
                 print(OUTPUT_DELIMITER)
         if "json" in config.output:
+            if config.compact and report_jsons:
+                self.strip_code_blocks_from_json(report_jsons)
             if not report_jsons:
-                print(dumps(Report(None).get_summary(), indent=4))
+                print(dumps(Report("").get_summary(), indent=4, cls=CustomJSONEncoder))
+                data_outputs['json'] = json.dumps(Report("").get_summary(), cls=CustomJSONEncoder)
             elif len(report_jsons) == 1:
                 print(dumps(report_jsons[0], indent=4, cls=CustomJSONEncoder))
+                data_outputs['json'] = json.dumps(report_jsons[0], cls=CustomJSONEncoder)
             else:
                 print(dumps(report_jsons, indent=4, cls=CustomJSONEncoder))
+                data_outputs['json'] = json.dumps(report_jsons, cls=CustomJSONEncoder)
             output_formats.remove("json")
             if output_formats:
                 print(OUTPUT_DELIMITER)
         if "junitxml" in config.output:
-            if len(junit_reports) == 1:
-                junit_reports[0].print_junit_xml(use_bc_ids=config.output_bc_ids)
+            properties = Report.create_test_suite_properties_block(config)
+
+            if junit_reports:
+                test_suites = [
+                    report.get_test_suite(properties=properties, use_bc_ids=config.output_bc_ids)
+                    for report in junit_reports
+                ]
             else:
-                master_report = Report(None)
-                for report in junit_reports:
-                    master_report.skipped_checks += report.skipped_checks
-                    master_report.passed_checks += report.passed_checks
-                    master_report.failed_checks += report.failed_checks
-                master_report.print_junit_xml(use_bc_ids=config.output_bc_ids)
+                test_suites = [Report("").get_test_suite(properties=properties)]
+
+            data_outputs['junitxml'] = Report.get_junit_xml_string(test_suites)
+            print(data_outputs['junitxml'])
+
             output_formats.remove("junitxml")
             if output_formats:
                 print(OUTPUT_DELIMITER)
-
         if "cyclonedx" in config.output:
             if cyclonedx_reports:
                 # More than one Report - combine Reports first
@@ -182,12 +222,23 @@ class RunnerRegistry:
                 report = cyclonedx_reports[0]
             cyclonedx_output = ExtXml(bom=report.get_cyclonedx_bom())
             print(cyclonedx_output.output_as_string())
+            data_outputs['cyclonedx'] = cyclonedx_output.output_as_string()
             output_formats.remove("cyclonedx")
             if output_formats:
                 print(OUTPUT_DELIMITER)
 
+        # Save output to file
+        file_names = {'cli': 'results_cli.txt', 'github_failed_only': 'results_github_failed_only.txt',
+                      'sarif': 'results_sarif.sarif',
+                      'json': 'results_json.json', 'junitxml': 'results_junitxml.xml',
+                      'cyclonedx': 'results_cyclonedx.xml'}
+        if config.output_file_path:
+            for output in config.output:
+                self.save_output_to_file(file_name=f'{config.output_file_path}/{file_names[output]}',
+                                         data=data_outputs[output],
+                                         data_format=output)
         exit_code = 1 if 1 in exit_codes else 0
-        return exit_code
+        return cast(Literal[0, 1], exit_code)
 
     def filter_runner_framework(self) -> None:
         if not self.runner_filter:
@@ -198,22 +249,30 @@ class RunnerRegistry:
             return
         self.runners = [runner for runner in self.runners if runner.check_type in self.runner_filter.framework]
 
+    def filter_runners_for_files(self, files: List[str]) -> None:
+        if not files:
+            return
+
+        self.runners = [runner for runner in self.runners if any(runner.should_scan_file(file) for file in files)]
+        logging.debug(f'Filtered runners based on file type(s). Result: {[r.check_type for r in self.runners]}')
+
     def remove_runner(self, runner: BaseRunner) -> None:
         if runner in self.runners:
             self.runners.remove(runner)
 
     @staticmethod
-    def enrich_report_with_guidelines(scan_report: Report, guidelines: Dict[str, str]) -> None:
+    def enrich_report_with_guidelines(scan_report: Report) -> None:
         for record in itertools.chain(scan_report.failed_checks, scan_report.passed_checks, scan_report.skipped_checks):
-            if record.check_id in guidelines:
-                record.set_guideline(guidelines[record.check_id])
+            guideline = metadata_integration.get_guideline(record.check_id)
+            if guideline:
+                record.set_guideline(guideline)
 
     @staticmethod
-    def get_enriched_resources(repo_roots: List[Union[str, os.PathLike]]) -> Dict[str, Dict[str, Any]]:
+    def get_enriched_resources(repo_roots: list[str | Path]) -> dict[str, dict[str, Any]]:
         repo_definitions = {}
         for repo_root in repo_roots:
-            tf_definitions = {}
-            parsing_errors = {}
+            tf_definitions: dict[str, Any] = {}
+            parsing_errors: dict[str, Exception] = {}
             Parser().parse_directory(
                 directory=repo_root,  # assume plan file is in the repo-root
                 out_definitions=tf_definitions,
@@ -250,3 +309,20 @@ class RunnerRegistry:
                                 "skipped_checks": skipped_checks,
                             }
         return enriched_resources
+
+    def _get_image_referencing_runners(self) -> set[ImageReferencer]:
+        image_referencing_runners = set()
+        for runner in self.runners:
+            if issubclass(runner.__class__, ImageReferencer):
+                image_referencing_runners.add(cast(ImageReferencer, runner))
+
+        return image_referencing_runners
+
+    @staticmethod
+    def strip_code_blocks_from_json(report_jsons: List[Dict[str, Any]]) -> None:
+        for report in report_jsons:
+            results = report.get('results', {})
+            for key, result in results.items():
+                for result_dict in result:
+                    result_dict.pop('code_block', None)
+                    result_dict.pop('connected_node', None)
