@@ -1,7 +1,9 @@
+from __future__ import annotations
+
 import json
 import logging
 from json import JSONDecodeError
-from typing import TypeVar, List, overload, Union, Optional, Any, Dict
+from typing import TypeVar, overload, Any
 
 import yaml
 
@@ -9,22 +11,22 @@ T = TypeVar("T")
 
 
 @overload
-def force_list(var: List[T]) -> List[T]:
+def force_list(var: list[T]) -> list[T]:
     ...
 
 
 @overload
-def force_list(var: T) -> List[T]:
+def force_list(var: T) -> list[T]:
     ...
 
 
-def force_list(var: Union[T, List[T]]) -> List[T]:
+def force_list(var: T | list[T]) -> list[T]:
     if not isinstance(var, list):
         return [var]
     return var
 
 
-def force_int(var: Any) -> Optional[int]:
+def force_int(var: Any) -> int | None:
     try:
         if not isinstance(var, int):
             return int(var)
@@ -33,7 +35,7 @@ def force_int(var: Any) -> Optional[int]:
         return None
 
 
-def force_float(var: Any) -> Optional[float]:
+def force_float(var: Any) -> float | None:
     try:
         if not isinstance(var, float):
             return float(var)
@@ -42,7 +44,7 @@ def force_float(var: Any) -> Optional[float]:
         return None
 
 
-def convert_str_to_bool(bool_str: Union[bool, str]) -> Union[bool, str]:
+def convert_str_to_bool(bool_str: bool | str) -> bool | str:
     if bool_str in ["true", '"true"', "True", '"True"']:
         return True
     elif bool_str in ["false", '"false"', "False", '"False"']:
@@ -51,7 +53,7 @@ def convert_str_to_bool(bool_str: Union[bool, str]) -> Union[bool, str]:
         return bool_str
 
 
-def force_dict(obj: Any) -> Optional[Dict[str, Any]]:
+def force_dict(obj: Any) -> dict[str, Any] | None:
     """
     If the specified object is a dict, returns the object. If the object is a list of length 1 or more, and the first
     element is a dict, returns the first element. Else returns None.
@@ -83,12 +85,12 @@ def is_yaml(data: str) -> bool:
         return False
 
 
-def extract_policy_dict(policy: Union[dict, str]) -> Optional[dict]:
+def extract_policy_dict(policy: dict[str, Any] | str) -> dict[str, Any] | None:
     if isinstance(policy, dict):
         return policy
     if isinstance(policy, str):
         try:
-            policy_dict = json.loads(policy)
+            policy_dict: dict[str, Any] = json.loads(policy)
             return policy_dict
         except JSONDecodeError:
             return None
@@ -96,7 +98,7 @@ def extract_policy_dict(policy: Union[dict, str]) -> Optional[dict]:
     return None
 
 
-def convert_csv_string_arg_to_list(csv_string_arg: Union[List[str], str, None]) -> list:
+def convert_csv_string_arg_to_list(csv_string_arg: list[str] | str | None) -> list[str]:
     """
     Converts list type arguments that also support comma delimited strings into a list.
     For instance the --check flag in the CLI:
@@ -113,4 +115,3 @@ def convert_csv_string_arg_to_list(csv_string_arg: Union[List[str], str, None])
         return csv_string_arg[0].split(',')
     else:
         return csv_string_arg
-
