@@ -1,26 +1,23 @@
 import logging
 import os
-import re
 from typing import List, Dict, Tuple
 
 from checkov.common.output.record import Record
-from checkov.common.output.report import Report
+from checkov.common.output.report import Report, CheckType
 from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.parsers.node import DictNode
 from checkov.common.runners.base_runner import BaseRunner, filter_ignored_paths
+from checkov.dockerfile.utils import is_docker_file
 from checkov.dockerfile.parser import parse, collect_skipped_checks
 from checkov.dockerfile.registry import registry
 from checkov.runner_filter import RunnerFilter
 
-DOCKER_FILE_MASK = re.compile(r"^(?:.+\.)?[Dd]ockerfile(?:\..+)?$")
-
 
 class Runner(BaseRunner):
-    check_type = "dockerfile"
+    check_type = CheckType.DOCKERFILE
 
-    @staticmethod
-    def _is_docker_file(file):
-        return re.fullmatch(DOCKER_FILE_MASK, file) is not None
+    def should_scan_file(self, filename: str) -> bool:
+        return is_docker_file(os.path.basename(filename))
 
     def run(self, root_folder=None, external_checks_dir=None, files=None, runner_filter=RunnerFilter(),
             collect_skip_comments=True):
@@ -32,7 +29,7 @@ class Runner(BaseRunner):
                 registry.load_external_checks(directory)
 
         if files:
-            files_list = [file for file in files if Runner._is_docker_file(os.path.basename(file))]
+            files_list = [file for file in files if is_docker_file(os.path.basename(file))]
 
         if root_folder:
             filepath_fn = lambda f: f'/{os.path.relpath(f, os.path.commonprefix((root_folder, f)))}'
@@ -40,7 +37,7 @@ class Runner(BaseRunner):
                 filter_ignored_paths(root, d_names, runner_filter.excluded_paths)
                 filter_ignored_paths(root, f_names, runner_filter.excluded_paths)
                 for file in f_names:
-                    if Runner._is_docker_file(file):
+                    if is_docker_file(file):
                         file_path = os.path.join(root, file)
                         files_list.append(file_path)
 
@@ -70,22 +67,43 @@ class Runner(BaseRunner):
                 endline = len(definitions_raw[docker_file_path]) - 1
                 result_instruction = ""
                 if result_configuration:
-                    startline = result_configuration['startline']
-                    endline = result_configuration['endline']
-                    result_instruction = result_configuration["instruction"]
-
-                codeblock = []
-                self.calc_record_codeblock(codeblock, definitions_raw, docker_file_path, endline, startline)
-                record = Record(check_id=check.id, bc_check_id=check.bc_id, check_name=check.name, check_result=check_result,
-                                code_block=codeblock,
-                                file_path=docker_file_path,
-                                file_line_range=[startline + 1,
-                                                 endline + 1],
-                                resource=f"{docker_file_path}.{result_instruction}",
-                                evaluations=None, check_class=check.__class__.__module__,
-                                file_abs_path=file_abs_path, entity_tags=None)
-                record.set_guideline(check.guideline)
-                report.add_record(record=record)
+                    if isinstance(result_configuration,list):
+                        for res in result_configuration:
+                            startline = res['startline']
+                            endline = res['endline']
+                            result_instruction = res["instruction"]
+                            self.build_record(report, 
+                                              definitions_raw, 
+                                              docker_file_path, 
+                                              file_abs_path, 
+                                              check, 
+                                              check_result, 
+                                              startline, 
+                                              endline, 
+                                              result_instruction)
+                    else:
+                        startline = result_configuration['startline']
+                        endline = result_configuration['endline']
+                        result_instruction = result_configuration["instruction"]
+                        self.build_record(report, 
+                                          definitions_raw, 
+                                          docker_file_path, 
+                                          file_abs_path, 
+                                          check, 
+                                          check_result, 
+                                          startline,
+                                          endline, 
+                                          result_instruction)
+                else:
+                    self.build_record(report, 
+                                      definitions_raw, 
+                                      docker_file_path, 
+                                      file_abs_path, 
+                                      check, 
+                                      check_result, 
+                                      startline, 
+                                      endline, 
+                                      result_instruction)
 
         return report
 
@@ -93,6 +111,21 @@ class Runner(BaseRunner):
         for line in range(startline, endline + 1):
             codeblock.append((line + 1, definitions_raw[docker_file_path][line]))
 
+    def build_record(self, report, definitions_raw, docker_file_path, file_abs_path, check, check_result, startline, endline, result_instruction):
+        codeblock = []
+        self.calc_record_codeblock(codeblock, definitions_raw, docker_file_path, endline, startline)
+        record = Record(check_id=check.id, bc_check_id=check.bc_id, check_name=check.name, check_result=check_result,
+                                code_block=codeblock,
+                                file_path=docker_file_path,
+                                file_line_range=[startline + 1,
+                                                 endline + 1],
+                                resource=f"{docker_file_path}.{result_instruction}",
+                                evaluations=None, check_class=check.__class__.__module__,
+                                file_abs_path=file_abs_path, entity_tags=None,
+                                severity=check.severity)
+        record.set_guideline(check.guideline)
+        report.add_record(record=record)
+
 
 def get_files_definitions(files: List[str], filepath_fn=None) \
         -> Tuple[Dict[str, DictNode], Dict[str, List[Tuple[int, str]]]]:
@@ -102,6 +135,9 @@ def get_files_definitions(files: List[str], filepath_fn=None) \
         except TypeError:
             logging.info(f'Dockerfile skipping {file} as it is not a valid dockerfile template')
             return file, None
+        except UnicodeDecodeError:
+            logging.info(f'Dockerfile skipping {file} as it can\'t be read as text file')
+            return file, None
 
     results = parallel_runner.run_function(_parse_file, files)
     definitions = {}
