@@ -1,22 +1,19 @@
-from checkov.common.models.enums import CheckCategories, CheckResult
-from checkov.kubernetes.checks.resource.base_spec_check import BaseK8Check
+from typing import Any, Dict
+
+from checkov.common.models.enums import CheckResult
+from checkov.kubernetes.checks.resource.base_container_check import BaseK8sContainerCheck
 
 
-class MinimizeCapabilities(BaseK8Check):
-
-    def __init__(self):
+class MinimizeCapabilities(BaseK8sContainerCheck):
+    def __init__(self) -> None:
         # CIS-1.5 5.2.9
         name = "Minimize the admission of containers with capabilities assigned"
         id = "CKV_K8S_37"
         # Location: container .securityContext.capabilities.drop
-        supported_kind = ['containers', 'initContainers']
-        categories = [CheckCategories.KUBERNETES]
-        super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
+        super().__init__(name=name, id=id)
 
-    def get_resource_id(self, conf):
-        return f'{conf["parent"]} - {conf["name"]}' if conf.get('name') else conf["parent"]
-
-    def scan_spec_conf(self, conf):
+    def scan_container_conf(self, metadata: Dict[str, Any], conf: Dict[str, Any]) -> CheckResult:
+        self.evaluated_container_keys = ["securityContext/capabilities/drop"]
         if conf.get("securityContext"):
             if conf["securityContext"].get("capabilities"):
                 if conf["securityContext"]["capabilities"].get("drop"):
