@@ -1,10 +1,8 @@
-
-from checkov.common.models.enums import CheckCategories, CheckResult
-from checkov.kubernetes.checks.resource.base_spec_check import BaseK8Check
+from checkov.common.models.enums import CheckResult
+from checkov.kubernetes.checks.resource.base_root_container_check import BaseK8sRootContainerCheck
 
 
-class RootContainers(BaseK8Check):
-
+class RootContainers(BaseK8sRootContainerCheck):
     def __init__(self):
         # CIS-1.3 1.7.6
         # CIS-1.5 5.2.6
@@ -14,40 +12,20 @@ class RootContainers(BaseK8Check):
         # Location: CronJob.spec.jobTemplate.spec.template.spec.securityContext.runAsUser / runAsNonRoot
         # Location: *.spec.template.spec.securityContext.runAsUser / runAsNonRoot
         id = "CKV_K8S_23"
-        supported_kind = ['Pod', 'Deployment', 'DaemonSet', 'StatefulSet', 'ReplicaSet', 'ReplicationController', 'Job', 'CronJob']
-        categories = [CheckCategories.KUBERNETES]
-        super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
+        super().__init__(name=name, id=id)
 
     def scan_spec_conf(self, conf):
-        spec = {}
-
-        if conf['kind'] == 'Pod':
-            if "spec" in conf:
-                spec = conf["spec"]
-        elif conf['kind'] == 'CronJob':
-            if "spec" in conf:
-                if "jobTemplate" in conf["spec"]:
-                    if "spec" in conf["spec"]["jobTemplate"]:
-                        if "template" in conf["spec"]["jobTemplate"]["spec"]:
-                            if "spec" in conf["spec"]["jobTemplate"]["spec"]["template"]:
-                                spec = conf["spec"]["jobTemplate"]["spec"]["template"]["spec"]
-        else:
-            inner_spec = self.get_inner_entry(conf, "spec")
-            spec = inner_spec if inner_spec else spec
+        spec = self.extract_spec(conf)
 
         # Collect results
         if spec:
-            results = {}
-            results["pod"] = {}
-            results["container"] = []
-            results["pod"]["runAsNonRoot"] = check_runAsNonRoot(spec)
-            results["pod"]["runAsUser"] = check_runAsUser(spec)
+            results = {"pod": {}, "container": []}
+            results["pod"]["runAsNonRoot"] = self.check_runAsNonRoot(spec)
+            results["pod"]["runAsUser"] = self.check_runAsUser(spec, 1)
 
             if spec.get("containers"):
                 for c in spec["containers"]:
-                    cresults = {}
-                    cresults["runAsNonRoot"] = check_runAsNonRoot(c)
-                    cresults["runAsUser"] = check_runAsUser(c)
+                    cresults = {"runAsNonRoot": self.check_runAsNonRoot(c), "runAsUser": self.check_runAsUser(c, 1)}
                     results["container"].append(cresults)
 
             # Evaluate pass / fail
@@ -87,24 +65,5 @@ class RootContainers(BaseK8Check):
 
         return CheckResult.FAILED
 
+
 check = RootContainers()
-
-def check_runAsNonRoot(spec):
-    if spec.get("securityContext"):
-        if "runAsNonRoot" in spec["securityContext"]:
-            if spec["securityContext"]["runAsNonRoot"]:
-                return "PASSED"
-            else:
-                return "FAILED"
-    return "ABSENT"
-
-def check_runAsUser(spec):
-    if spec.get("securityContext"):
-        if "runAsUser" in spec["securityContext"]:
-            if spec["securityContext"]["runAsUser"] > 0:
-                return "PASSED"
-            else:
-                return "FAILED"
-    return "ABSENT"
-
-
