@@ -11,8 +11,8 @@ from checkov.common.graph.graph_builder import CustomAttributes
 from checkov.common.graph.graph_builder.local_graph import LocalGraph
 from checkov.common.graph.graph_manager import GraphManager
 from checkov.common.output.record import Record
-from checkov.common.output.report import Report, merge_reports
-from checkov.common.runners.base_runner import BaseRunner
+from checkov.common.output.report import Report, merge_reports, CheckType
+from checkov.common.runners.base_runner import BaseRunner, CHECKOV_CREATE_GRAPH
 from checkov.kubernetes.checks.resource.registry import registry
 from checkov.kubernetes.graph_builder.local_graph import KubernetesLocalGraph
 from checkov.kubernetes.graph_manager import KubernetesGraphManager
@@ -29,14 +29,16 @@ class Runner(BaseRunner):
         graph_manager: Optional[GraphManager] = None,
         external_registries: Optional[List[BaseRegistry]] = None
     ) -> None:
+        super().__init__(file_extensions=['.yml', '.yaml'])
         self.external_registries = [] if external_registries is None else external_registries
-        self.check_type = "kubernetes"
+        self.check_type = CheckType.KUBERNETES
         self.graph_class = graph_class
         self.graph_manager = \
             graph_manager if graph_manager else KubernetesGraphManager(source=source, db_connector=db_connector)
 
         self.graph_registry = get_graph_checks_registry(self.check_type)
         self.definitions_raw = {}
+        self.report_mutator_data = None
 
     def run(self, root_folder, external_checks_dir=None, files=None, runner_filter=RunnerFilter(), collect_skip_comments=True, helmChart=None):
         report = Report(self.check_type)
@@ -48,24 +50,32 @@ class Runner(BaseRunner):
             if external_checks_dir:
                 for directory in external_checks_dir:
                     registry.load_external_checks(directory)
-                    self.graph_registry.load_external_checks(directory)
+
+                    if CHECKOV_CREATE_GRAPH:
+                        self.graph_registry.load_external_checks(directory)
+
             self.context = build_definitions_context(self.definitions, self.definitions_raw)
 
-            logging.info("creating kubernetes graph")
-            local_graph = self.graph_manager.build_graph_from_definitions(self.definitions)
-            for vertex in local_graph.vertices:
-                file_abs_path = _get_entity_abs_path(root_folder, vertex.path)
-                report.add_resource(f'{file_abs_path}:{vertex.id}')
-            self.graph_manager.save_graph(local_graph)
-            self.definitions = local_graph.definitions
+            if CHECKOV_CREATE_GRAPH:
+                logging.info("creating Kubernetes graph")
+                local_graph = self.graph_manager.build_graph_from_definitions(self.definitions)
+                logging.info("Successfully created Kubernetes graph")
 
-        report = self.check_definitions(root_folder, runner_filter, report)
-        graph_report = self.get_graph_checks_report(root_folder, runner_filter)
-        merge_reports(report, graph_report)
+                for vertex in local_graph.vertices:
+                    file_abs_path = _get_entity_abs_path(root_folder, vertex.path)
+                    report.add_resource(f'{file_abs_path}:{vertex.id}')
+                self.graph_manager.save_graph(local_graph)
+                self.definitions = local_graph.definitions
+
+        report = self.check_definitions(root_folder, runner_filter, report, collect_skip_comments=collect_skip_comments, helmChart=helmChart)
+
+        if CHECKOV_CREATE_GRAPH:
+            graph_report = self.get_graph_checks_report(root_folder, runner_filter, helmChart=helmChart)
+            merge_reports(report, graph_report)
 
         return report
 
-    def check_definitions(self, root_folder, runner_filter, report):
+    def check_definitions(self, root_folder, runner_filter, report, collect_skip_comments=True, helmChart=None,):
         for k8_file in self.definitions.keys():
             # There are a few cases here. If -f was used, there could be a leading / because it's an absolute path,
             # or there will be no leading slash; root_folder will always be none.
@@ -77,7 +87,9 @@ class Runner(BaseRunner):
             for entity_conf in self.definitions[k8_file]:
                 entity_type = entity_conf.get("kind")
 
-                # Skip List and Kustomization Templates (for now)
+                # Skip Kustomization Templates. 
+                # Should be handled by Kusomize framework handler when it finds kustomization.yaml files.
+                # TODO: FUTURE: Potentially call the framework if we find items here that aren't in a file called kustomization.yaml - validate this edge case.
                 if entity_type == "Kustomization":
                     continue
 
@@ -87,25 +99,39 @@ class Runner(BaseRunner):
                 # TODO? - Variable Eval Message!
                 variable_evaluations = {}
 
-                for check, check_result in results.items():
-                    resource_id = get_resource_id(entity_conf)
-                    entity_context = self.context[k8_file][resource_id]
-
-                    record = Record(
-                        check_id=check.id, bc_check_id=check.bc_id, check_name=check.name,
-                        check_result=check_result, code_block=entity_context.get("code_lines"), file_path=k8_file_path,
-                        file_line_range=[entity_context.get("start_line"), entity_context.get("end_line")],
-                        resource=resource_id, evaluations=variable_evaluations,
-                        check_class=check.__class__.__module__, file_abs_path=file_abs_path)
-                    record.set_guideline(check.guideline)
-                    report.add_record(record=record)
+                report = self.mutateKubernetesResults(results, report, k8_file, k8_file_path, file_abs_path, entity_conf, variable_evaluations)
 
         return report
 
-    def get_graph_checks_report(self, root_folder: str, runner_filter: RunnerFilter) -> Report:
+    def get_graph_checks_report(self, root_folder: str, runner_filter: RunnerFilter, helmChart) -> Report:
         report = Report(self.check_type)
         checks_results = self.run_graph_checks_results(runner_filter)
+        report = self.mutateKubernetesGraphResults(root_folder, runner_filter, report, checks_results)
+        return report
 
+    def mutateKubernetesResults(self, results, report, k8_file=None, k8_file_path=None, file_abs_path=None, entity_conf=None, variable_evaluations=None):
+        # Moves report generation logic out of run() method in Runner class.
+        # Allows function overriding of a much smaller function than run() for other "child" frameworks such as Kustomize, Helm
+        # Where Kubernetes CHECKS are needed, but the specific file references are to another framework for the user output (or a mix of both).
+        for check, check_result in results.items():
+            resource_id = get_resource_id(entity_conf)
+            entity_context = self.context[k8_file][resource_id]
+
+            record = Record(
+                check_id=check.id, bc_check_id=check.bc_id, check_name=check.name,
+                check_result=check_result, code_block=entity_context.get("code_lines"), file_path=k8_file_path,
+                file_line_range=[entity_context.get("start_line"), entity_context.get("end_line")],
+                resource=resource_id, evaluations=variable_evaluations,
+                check_class=check.__class__.__module__, file_abs_path=file_abs_path, severity=check.severity)
+            record.set_guideline(check.guideline)
+            report.add_record(record=record)
+        
+        return report
+
+    def mutateKubernetesGraphResults(self, root_folder: str, runner_filter: RunnerFilter, report: Report, checks_results) -> Report:
+        # Moves report generation logic out of run() method in Runner class.
+        # Allows function overriding of a much smaller function than run() for other "child" frameworks such as Kustomize, Helm
+        # Where Kubernetes CHECKS are needed, but the specific file references are to another framework for the user output (or a mix of both).
         for check, check_results in checks_results.items():
             for check_result in check_results:
                 entity = check_result["entity"]
@@ -124,7 +150,8 @@ class Runner(BaseRunner):
                     resource=entity.get(CustomAttributes.ID),
                     evaluations={},
                     check_class=check.__class__.__module__,
-                    file_abs_path=entity_file_abs_path
+                    file_abs_path=entity_file_abs_path,
+                    severity=check.severity
                 )
                 record.set_guideline(check.guideline)
                 report.add_record(record=record)
