@@ -19,7 +19,7 @@ from checkov.serverless.checks.service.registry import service_registry
 from checkov.common.runners.base_runner import BaseRunner, filter_ignored_paths
 from checkov.runner_filter import RunnerFilter
 from checkov.common.output.record import Record
-from checkov.common.output.report import Report
+from checkov.common.output.report import Report, CheckType
 from checkov.serverless.parsers.parser import parse
 from checkov.common.parsers.node import DictNode
 from checkov.serverless.parsers.parser import CFN_RESOURCES_TOKEN
@@ -41,7 +41,10 @@ SINGLE_ITEM_SECTIONS = [
 
 
 class Runner(BaseRunner):
-    check_type = "serverless"
+    check_type = CheckType.SERVERLESS
+
+    def __init__(self):
+        super().__init__(file_names=SLS_FILE_MASK)
 
     def run(self, root_folder, external_checks_dir=None, files=None, runner_filter=RunnerFilter(), collect_skip_comments=True):
         report = Report(self.check_type)
@@ -95,11 +98,12 @@ class Runner(BaseRunner):
 
             if CFN_RESOURCES_TOKEN in sls_file_data and isinstance(sls_file_data[CFN_RESOURCES_TOKEN], DictNode):
                 cf_sub_template = sls_file_data[CFN_RESOURCES_TOKEN]
-                if cf_sub_template.get("Resources"):
+                cf_sub_resources = cf_sub_template.get("Resources")
+                if cf_sub_resources and isinstance(cf_sub_resources, dict):
                     cf_context_parser = CfnContextParser(sls_file, cf_sub_template, definitions_raw[sls_file])
                     logging.debug(f"Template Dump for {sls_file}: {sls_file_data}")
                     cf_context_parser.evaluate_default_refs()
-                    for resource_name, resource in cf_sub_template['Resources'].items():
+                    for resource_name, resource in cf_sub_resources.items():
                         if not isinstance(resource, DictNode):
                             continue
                         cf_resource_id = cf_context_parser.extract_cf_resource_id(resource, resource_name)
@@ -123,7 +127,7 @@ class Runner(BaseRunner):
                                                 file_line_range=entity_lines_range,
                                                 resource=cf_resource_id, evaluations=variable_evaluations,
                                                 check_class=check.__class__.__module__, file_abs_path=file_abs_path,
-                                                entity_tags=tags)
+                                                entity_tags=tags, severity=check.severity)
                                 record.set_guideline(check.guideline)
                                 report.add_record(record=record)
 
@@ -141,7 +145,7 @@ class Runner(BaseRunner):
                     if entity_lines_range and entity_code_lines:
                         skipped_checks = CfnContextParser.collect_skip_comments(entity_code_lines)
                         variable_evaluations = {}
-                        if token == "functions": #nosec
+                        if token == "functions":  # nosec
                             # "Enriching" copies things like "environment" and "stackTags" down into the
                             # function data from the provider block since logically that's what serverless
                             # does. This allows checks to see what the complete data would be.
@@ -155,7 +159,7 @@ class Runner(BaseRunner):
                                             file_line_range=entity_lines_range,
                                             resource=item_name, evaluations=variable_evaluations,
                                             check_class=check.__class__.__module__, file_abs_path=file_abs_path,
-                                            entity_tags=tags)
+                                            entity_tags=tags, severity=check.severity)
                             record.set_guideline(check.guideline)
                             report.add_record(record=record)
             # Sub-sections that are a single item
@@ -178,7 +182,7 @@ class Runner(BaseRunner):
                                     file_line_range=entity_lines_range,
                                     resource=token, evaluations=variable_evaluations,
                                     check_class=check.__class__.__module__, file_abs_path=file_abs_path,
-                                    entity_tags=tags)
+                                    entity_tags=tags, severity=check.severity)
                     record.set_guideline(check.guideline)
                     report.add_record(record=record)
 
@@ -199,7 +203,7 @@ class Runner(BaseRunner):
                                     resource="complete",        # Weird, not sure what to put where
                                     evaluations=variable_evaluations,
                                     check_class=check.__class__.__module__, file_abs_path=file_abs_path,
-                                    entity_tags=tags)
+                                    entity_tags=tags, severity=check.severity)
                     record.set_guideline(check.guideline)
                     report.add_record(record=record)
 
