@@ -1,4 +1,3 @@
-import re
 from typing import Dict, List, Any
 
 from checkov.common.models.enums import CheckResult, CheckCategories
@@ -14,13 +13,13 @@ class OciCredentials(BaseProviderCheck):
         super().__init__(name=name, id=id, categories=categories, supported_provider=supported_provider)
 
     def scan_provider_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
-        key = 'private_key_password'
+        key = "private_key_password"
         if key in conf.keys():
-           if not conf[key]:
-               return CheckResult.PASSED
-           return CheckResult.FAILED
+            if not conf[key]:
+                return CheckResult.PASSED
+            return CheckResult.FAILED
         else:
-           return CheckResult.PASSED
+            return CheckResult.PASSED
 
 
 check = OciCredentials()
