@@ -1,5 +1,6 @@
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
+from typing import List
 
 
 class APIGatewayAuthorization(BaseResourceCheck):
@@ -12,10 +13,13 @@ class APIGatewayAuthorization(BaseResourceCheck):
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf):
-        self.evaluated_keys = ['http_method', 'authorization']
-        if conf['http_method'][0] != "OPTIONS" and conf['authorization'][0] == "NONE":
+        if conf['http_method'][0] != "OPTIONS" and conf['authorization'][0] == "NONE" \
+                and ('api_key_required' not in conf or conf['api_key_required'][0] is False):
             return CheckResult.FAILED
         return CheckResult.PASSED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ['http_method', 'authorization', 'api_key_required']
+
 
 check = APIGatewayAuthorization()
