@@ -1,5 +1,6 @@
 from checkov.common.models.enums import CheckCategories, CheckResult
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
+from typing import List
 
 
 class AzureDefenderOnKubernetes(BaseResourceCheck):
@@ -14,5 +15,8 @@ class AzureDefenderOnKubernetes(BaseResourceCheck):
         return CheckResult.PASSED if conf.get('resource_type', [None])[0] != 'KubernetesService' \
                                      or conf.get('tier', [None])[0] == 'Standard' else CheckResult.FAILED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ['resource_type', 'tier']
+
 
 check = AzureDefenderOnKubernetes()
