@@ -1,4 +1,4 @@
-from typing import Dict, List, Any
+from typing import Any
 
 from checkov.common.models.enums import CheckCategories, CheckResult
 from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
@@ -12,10 +12,10 @@ class WebhookInsecureSsl(BaseResourceValueCheck):
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources,
                          missing_block_result=CheckResult.PASSED)
 
-    def get_inspected_key(self):
+    def get_inspected_key(self) -> str:
         return "configuration/[0]/insecure_ssl/[0]"
 
-    def get_expected_value(self):
+    def get_expected_value(self) -> Any:
         return False
 
 
