@@ -104,8 +104,9 @@ class TerraformBlock(Block):
         cls,
         attribute_key: str,
         attribute_value: Union[str, List[str], Dict[str, Any]],
+        strip_list: bool = True
     ) -> Dict[str, Any]:
-        if isinstance(attribute_value, list) and len(attribute_value) == 1:
+        if strip_list and isinstance(attribute_value, list) and len(attribute_value) == 1:
             attribute_value = attribute_value[0]
 
         return super().get_inner_attributes(
