@@ -8,18 +8,17 @@ from typing import List, Optional, Union, Any, Dict, Set, Tuple
 from typing_extensions import TypedDict
 
 from checkov.common.graph.graph_builder import Edge
-from checkov.common.graph.graph_builder import reserved_attribute_names, EncryptionValues
+from checkov.common.graph.graph_builder import reserved_attribute_names
+from checkov.common.graph.graph_builder.graph_components.attribute_names import CustomAttributes
 from checkov.common.graph.graph_builder.local_graph import LocalGraph
-from checkov.common.graph.graph_builder.utils import calculate_hash, join_trimmed_strings
+from checkov.common.graph.graph_builder.utils import calculate_hash, join_trimmed_strings, filter_sub_keys
 from checkov.terraform.checks.utils.dependency_path_handler import unify_dependency_path
-from checkov.terraform.graph_builder.graph_components.attribute_names import CustomAttributes
 from checkov.terraform.graph_builder.graph_components.block_types import BlockType
 from checkov.terraform.graph_builder.graph_components.blocks import TerraformBlock
 from checkov.terraform.graph_builder.graph_components.generic_resource_encryption import ENCRYPTION_BY_RESOURCE_TYPE
 from checkov.terraform.graph_builder.graph_components.module import Module
 from checkov.terraform.graph_builder.utils import (
     get_referenced_vertices_in_value,
-    filter_sub_keys,
     attribute_has_nested_attributes, remove_index_pattern_from_str,
 )
 from checkov.terraform.graph_builder.utils import is_local_path
@@ -48,7 +47,7 @@ class TerraformLocalGraph(LocalGraph):
     def build_graph(self, render_variables: bool) -> None:
         self._create_vertices()
         self._build_edges()
-        self.calculate_encryption_attribute()
+        self.calculate_encryption_attribute(ENCRYPTION_BY_RESOURCE_TYPE)
         if render_variables:
             logging.info(f"Rendering variables, graph has {len(self.vertices)} vertices and {len(self.edges)} edges")
             renderer = TerraformVariableRenderer(self)
@@ -125,7 +124,7 @@ class TerraformLocalGraph(LocalGraph):
         For each vertex, if it's originated in a module import, add to the vertex the index of the
         matching module vertex as 'source_module'
         """
-        block_dirs_to_modules: Dict[Tuple[str, str], Set[int]] = {}
+        block_dirs_to_modules: Dict[Tuple[str, str], Dict[str, Set[int]]] = defaultdict(dict)
         for dir_name, paths_to_modules in self.module.module_dependency_map.items():
             # for each directory, find the module vertex that imported it
             for path_to_module in paths_to_modules:
@@ -137,22 +136,27 @@ class TerraformLocalGraph(LocalGraph):
                 module_list = self.map_path_to_module.get(path_to_module[-1], [])
                 for module_index in module_list:
                     module_vertex = self.vertices[module_index]
-                    module_vertex_dir = self.get_dirname(module_vertex.path)
-                    module_source = module_vertex.attributes.get("source", [""])[0]
-                    module_version = module_vertex.attributes.get("version", ["latest"])[0]
-                    dest_module_path = self._get_dest_module_path(
-                        curr_module_dir=module_vertex_dir,
-                        dest_module_source=module_source,
-                        dest_module_version=module_version
-                    )
-                    if dest_module_path == dir_name:
-                        block_dirs_to_modules.setdefault((dir_name, path_to_module_str), set()).add(module_index)
+                    if module_vertex.module_dependency == unify_dependency_path(path_to_module[:-1]):
+                        module_vertex_dir = self.get_dirname(module_vertex.path)
+                        module_source = module_vertex.attributes.get("source", [""])[0]
+                        module_version = module_vertex.attributes.get("version", ["latest"])[0]
+                        dest_module_path = self._get_dest_module_path(
+                            curr_module_dir=module_vertex_dir,
+                            dest_module_source=module_source,
+                            dest_module_version=module_version
+                        )
+                        if dest_module_path == dir_name:
+                            module_dependency_num = self.module.module_address_map.get((module_vertex.path, module_vertex.name))
+                            if module_dependency_num:
+                                block_dirs_to_modules[(dir_name, path_to_module_str)].setdefault(module_dependency_num, set()).add(module_index)
 
         for vertex in self.vertices:
             # match the right module vertex according to the vertex path directory
-            module_indices = block_dirs_to_modules.get((self.get_dirname(vertex.path), vertex.module_dependency), set())
-            if module_indices:
-                vertex.source_module = module_indices
+            module_dependency_nums = block_dirs_to_modules.get((self.get_dirname(vertex.path), vertex.module_dependency))
+            if module_dependency_nums:
+                module_indices = module_dependency_nums.get(vertex.module_dependency_num)
+                if module_indices:
+                    vertex.source_module = module_indices
 
     def _build_edges(self) -> None:
         logging.info("Creating edges")
@@ -370,6 +374,10 @@ class TerraformLocalGraph(LocalGraph):
             self.update_vertex_config(vertex, changed_attributes)
 
     def update_vertex_config(self, vertex: TerraformBlock, changed_attributes: Union[List[str], Dict[str, Any]]) -> None:
+        if not changed_attributes:
+            # skip, if there is no change
+            return
+
         updated_config = deepcopy(vertex.config)
         if vertex.block_type != BlockType.LOCALS:
             parts = vertex.name.split(".")
@@ -435,20 +443,6 @@ class TerraformLocalGraph(LocalGraph):
                 return True
         return False
 
-    def calculate_encryption_attribute(self) -> None:
-        for vertex_index in self.vertices_by_block_type.get(BlockType.RESOURCE, []):
-            vertex = self.vertices[vertex_index]
-            resource_type = vertex.id.split(".")[0]
-            encryption_conf = ENCRYPTION_BY_RESOURCE_TYPE.get(resource_type)
-            if encryption_conf:
-                attributes = vertex.get_attribute_dict()
-                is_encrypted, reason = encryption_conf.is_encrypted(attributes)
-                # TODO: Does not support possible dependency (i.e. S3 Object being encrypted due to S3 Bucket config)
-                vertex.attributes[CustomAttributes.ENCRYPTION] = (
-                    EncryptionValues.ENCRYPTED.value if is_encrypted else EncryptionValues.UNENCRYPTED.value
-                )
-                vertex.attributes[CustomAttributes.ENCRYPTION_DETAILS] = reason
-
     def get_dirname(self, path: str) -> str:
         dir_name = self.dirname_cache.get(path)
         if not dir_name:
