@@ -1,12 +1,13 @@
 import json
 import logging
 import os
+from typing import Optional, List
 
 from checkov.common.checks_infra.registry import get_graph_checks_registry
-from checkov.terraform.graph_builder.graph_components.attribute_names import CustomAttributes
+from checkov.common.graph.graph_builder.graph_components.attribute_names import CustomAttributes
 
 from checkov.common.output.record import Record
-from checkov.common.output.report import Report
+from checkov.common.output.report import Report, CheckType
 from checkov.common.runners.base_runner import filter_ignored_paths
 from checkov.runner_filter import RunnerFilter
 from checkov.terraform.checks.resource.registry import resource_registry
@@ -16,10 +17,11 @@ from checkov.terraform.runner import Runner as TerraformRunner, merge_reports
 
 
 class Runner(TerraformRunner):
-    check_type = "terraform_plan"
+    check_type = CheckType.TERRAFORM_PLAN
 
     def __init__(self):
         super().__init__()
+        self.file_extensions = ['.json']  # override what gets set from the TF runner
         self.template_lines = {}
         self.graph_registry = get_graph_checks_registry(super().check_type)
 
@@ -27,8 +29,14 @@ class Runner(TerraformRunner):
         'resource': resource_registry,
     }
 
-    def run(self, root_folder=None, external_checks_dir=None, files=None, runner_filter=RunnerFilter(),
-            collect_skip_comments=True):
+    def run(
+        self,
+        root_folder: Optional[str] = None,
+        external_checks_dir: Optional[List[str]] = None,
+        files: Optional[List[str]] = None,
+        runner_filter: RunnerFilter = RunnerFilter(),
+        collect_skip_comments: bool = True
+    ) -> Report:
         report = Report(self.check_type)
         self.tf_definitions = {}
         parsing_errors = {}
@@ -54,12 +62,13 @@ class Runner(TerraformRunner):
                             logging.debug(f'Failed to load json file {root}/{file}, skipping')
                             logging.debug('Failure message:')
                             logging.debug(e, stack_info=True)
+                            parsing_errors[file] = str(e)
 
         if files:
             files = [os.path.abspath(file) for file in files]
             for file in files:
                 if file.endswith(".json"):
-                    tf_definitions, template_lines = parse_tf_plan(file)
+                    tf_definitions, template_lines = parse_tf_plan(file, parsing_errors)
                     if not tf_definitions:
                         continue
                     self.tf_definitions = tf_definitions
@@ -68,7 +77,7 @@ class Runner(TerraformRunner):
                 else:
                     logging.debug(f'Failed to load {file} as is not a .json file, skipping')
 
-        report.add_parsing_errors(list(parsing_errors.keys()))
+        report.add_parsing_errors(parsing_errors.keys())
 
         if self.tf_definitions:
             graph = self.graph_manager.build_graph_from_definitions(self.tf_definitions, render_variables=False)
@@ -112,7 +121,8 @@ class Runner(TerraformRunner):
                                     code_block=entity_code_lines, file_path=scanned_file,
                                     file_line_range=entity_lines_range,
                                     resource=entity_id, resource_address=entity_address, evaluations=None,
-                                    check_class=check.__class__.__module__, file_abs_path=full_file_path)
+                                    check_class=check.__class__.__module__, file_abs_path=full_file_path,
+                                    severity=check.severity)
                     record.set_guideline(check.guideline)
                     report.add_record(record=record)
 
